Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(473)

Unified Diff: net/tools/quic/quic_simple_server_session_test.cc

Issue 1874613002: relnote: add connection option "SPSH" to indicate whether client wants to do server push or not, wh… (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/tools/quic/quic_simple_server_session.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/tools/quic/quic_simple_server_session_test.cc
diff --git a/net/tools/quic/quic_simple_server_session_test.cc b/net/tools/quic/quic_simple_server_session_test.cc
index ccc9573c95f6da2a9d5deb53e5537c56ef41081a..40760ebe5f887c6c25c3dd2efb0f3e49932f37bd 100644
--- a/net/tools/quic/quic_simple_server_session_test.cc
+++ b/net/tools/quic/quic_simple_server_session_test.cc
@@ -396,6 +396,10 @@ class QuicSimpleServerSessionServerPushTest
// control blocks it.
QuicConfigPeer::SetReceivedInitialSessionFlowControlWindow(
&config_, kInitialSessionFlowControlWindowForTest);
+ // Enable server push.
+ QuicTagVector copt;
+ copt.push_back(kSPSH);
+ QuicConfigPeer::SetReceivedConnectionOptions(&config_, copt);
connection_ = new StrictMock<MockConnectionWithSendStreamData>(
&helper_, Perspective::IS_SERVER, SupportedVersions(GetParam()));
@@ -403,7 +407,7 @@ class QuicSimpleServerSessionServerPushTest
&crypto_config_,
&compressed_certs_cache_));
session_->Initialize();
// Needed to make new session flow control window work.
session_->OnConfigNegotiated();
visitor_ = QuicConnectionPeer::GetVisitor(connection_);
« no previous file with comments | « net/tools/quic/quic_simple_server_session.cc ('k') | no next file » | no next file with comments »
@@ -403,7 +407,7 @@ class QuicSimpleServerSessionServerPushTest
&compressed_certs_cache_));
session_->Initialize();
- // Needed to make new session flow control window work.
+ // Needed to make new session flow control window and server push work.
session_->OnConfigNegotiated();
visitor_ = QuicConnectionPeer::GetVisitor(connection_);

Powered by Google App Engine
This is Rietveld 408576698